@@ -7,7 +7,7 @@ from zygoat.utils.shell import run
 from zygoat.constants import Projects
 
 from .dockerfile import dockerfile
-from .wait_command import wait_command
+from .command_component import management_command
 from .settings import settings
 from .gitignore import gitignore
 from .black import black
@@ -42,7 +42,7 @@ backend = Backend(
         settings,
         dockerfile,
         dependencies,
-        wait_command,
+        management_command,
         gitignore,
         black,
         banditrc,
