@@ -4,14 +4,6 @@ from zygoat.components import SettingsComponent
 
 log = logging.getLogger()
 
-security_headers = """\
-if not DEBUG:
-    SECURE_BROWSER_XSS_FILTER = True
-    SECURE_CONTENT_TYPE_NOSNIFF = True
-    SECURE_HSTS_SECONDS = 31536000
-    SECURE_HSTS_INCLUDE_SUBDOMAINS = True
-"""
-
 
 class Security(SettingsComponent):
     def create(self):
@@ -20,7 +12,16 @@ class Security(SettingsComponent):
         log.info("Adding security headers")
 
         red.extend(
-            ["\n", "# Set security headers", "\n", security_headers,]
+            [
+                "\n",
+                "# Set security headers",
+                "X_FRAME_OPTIONS = 'DENY'",
+                "SECURE_BROWSER_XSS_FILTER = True",
+                "SECURE_CONTENT_TYPE_NOSNIFF = True",
+                "SECURE_HSTS_SECONDS = 31536000",
+                "SECURE_HSTS_INCLUDE_SUBDOMAINS = True",
+                "\n",
+            ]
         )
         self.dump(red)
 
