@@ -12,8 +12,8 @@ from .prettier import prettier
 from .eslint import eslint
 from .cypress import cypress
 from .next_config import next_config
-from .proxy import proxy
 from .dependencies import dependencies
+from .jsconfig import js_config
 
 log = logging.getLogger()
 
@@ -24,7 +24,7 @@ class Frontend(Component):
         run(["npm", "install", "-g", "--upgrade", "yarn"])
 
         log.info("Running create-next-app")
-        run(["yarn", "create", "next-app", Projects.FRONTEND, "-e"])
+        run(["yarn", "create", "next-app", Projects.FRONTEND])
 
         log.info("Deleting a poorly formatted index page")
         open(os.path.join(Projects.FRONTEND, "pages", "index.js"), "w").close()
@@ -50,6 +50,6 @@ frontend = Frontend(
         eslint,
         cypress,
         next_config,
-        proxy,
+        js_config,
     ]
 )
