@@ -12,10 +12,7 @@ log = logging.getLogger()
 
 
 class Dependencies(Component):
-    dependencies = [
-        "prop-types",
-        "axios",
-    ]
+    dependencies = ["prop-types", "axios", "next-compose-plugins", "next-svgr", "next-images"]
     dev_dependencies = ["jest", "@testing-library/dom", "@testing-library/react"]
 
     def create(self):
